==> spring-credhub-starter-2.2.0-sources.jar: org/springframework/credhub/autoconfig/CredHubTemplateAutoConfiguration.java <==
/*
 * Copyright 2016-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.credhub.autoconfig;

import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.security.oauth2.client.reactive.ReactiveOAuth2ClientAutoConfiguration;
import org.springframework.boot.autoconfigure.security.oauth2.client.servlet.OAuth2ClientAutoConfiguration;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.credhub.core.CredHubProperties;
import org.springframework.credhub.core.CredHubTemplate;

/**
 * {@link EnableAutoConfiguration Auto-configuration} for {@link CredHubTemplate}.
 *
 * @author Scott Frederick
 */
@Configuration(proxyBeanMethods = false)
@AutoConfigureAfter({ CredHubAutoConfiguration.class, CredHubOAuth2AutoConfiguration.class,
		OAuth2ClientAutoConfiguration.class, ReactiveOAuth2ClientAutoConfiguration.class })
@ConditionalOnBean(CredHubProperties.class)
@Import({ CredHubTemplateConfiguration.class, ReactiveCredHubTemplateConfiguration.class })
public class CredHubTemplateAutoConfiguration {

}

==> spring-credhub-starter-2.3.0-sources.jar: org/springframework/credhub/autoconfig/CredHubTemplateAutoConfiguration.java <==
/*
 * Copyright 2016-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.credhub.autoconfig;

import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.security.oauth2.client.reactive.ReactiveOAuth2ClientAutoConfiguration;
import org.springframework.boot.autoconfigure.security.oauth2.client.servlet.OAuth2ClientAutoConfiguration;
import org.springframework.context.annotation.Import;
import org.springframework.credhub.core.CredHubProperties;
import org.springframework.credhub.core.CredHubTemplate;

/**
 * {@link EnableAutoConfiguration Auto-configuration} for {@link CredHubTemplate}.
 *
 * @author Scott Frederick
 */
@AutoConfiguration(after = { CredHubAutoConfiguration.class, CredHubOAuth2AutoConfiguration.class,
		OAuth2ClientAutoConfiguration.class, ReactiveOAuth2ClientAutoConfiguration.class })
@ConditionalOnBean(CredHubProperties.class)
@Import({ CredHubTemplateConfiguration.class, ReactiveCredHubTemplateConfiguration.class })
public class CredHubTemplateAutoConfiguration {

}
